@@ -17,11 +17,11 @@ Module::Starter::Simple - a simple, comprehensive Module::Starter plugin
 
 =head1 VERSION
 
-Version 1.62
+Version 1.70
 
 =cut
 
-our $VERSION = '1.62';
+our $VERSION = '1.70';
 
 =head1 SYNOPSIS
 
@@ -228,7 +228,7 @@ method eventually.)
 our $LICENSES = {
     perl => {
         license => 'perl',
-        slname  => 'Perl_5',
+        slname  => 'perl_5',
         url     => 'http://dev.perl.org/licenses/',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or modify it
@@ -240,7 +240,7 @@ EOT
     },
     artistic => {
         license => 'artistic',
-        slname  => 'Artistic_1_0',
+        slname  => 'artistic_1',
         url     => 'http://www.perlfoundation.org/artistic_license_1_0',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or modify it
@@ -266,7 +266,7 @@ EOT
     },
     artistic2 => {
         license => 'artistic2',
-        slname  => 'Artistic_2_0',
+        slname  => 'artistic_2',
         url     => 'http://www.perlfoundation.org/artistic_license_2_0',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or modify it
@@ -308,7 +308,7 @@ EOT
     },
     mit => {
         license => 'mit',
-        slname  => 'MIT',
+        slname  => 'mit',
         url     => 'http://www.opensource.org/licenses/mit-license.php',
         blurb   => <<'EOT',
 This program is distributed under the MIT (X11) License:
@@ -338,7 +338,7 @@ EOT
     },
     mozilla => {
         license => 'mozilla',
-        slname  => 'Mozilla_1_1',
+        slname  => 'mozilla_1_1',
         url     => 'http://www.mozilla.org/MPL/1.1/',
         blurb   => <<'EOT',
 The contents of this file are subject to the Mozilla Public License
@@ -354,7 +354,7 @@ EOT
     },
     mozilla2 => {
         license => 'mozilla2',
-        slname  => 'Mozilla_2_0',
+        slname  => 'open_source',
         url     => 'http://www.mozilla.org/MPL/2.0/',
         blurb   => <<'EOT',
 This Source Code Form is subject to the terms of the Mozilla Public
@@ -364,7 +364,7 @@ EOT
     },
     bsd => {
         license => 'bsd',
-        slname  => 'BSD',
+        slname  => 'bsd',
         url     => 'http://www.opensource.org/licenses/BSD-3-Clause',
         blurb   => <<"EOT",
 This program is distributed under the (Revised) BSD License:
@@ -401,7 +401,7 @@ EOT
     },
     freebsd => {
         license => 'freebsd',
-        slname  => 'FreeBSD',
+        slname  => 'freebsd',
         url     => 'http://www.opensource.org/licenses/BSD-2-Clause',
         blurb   => <<"EOT",
 This program is distributed under the (Simplified) BSD License:
@@ -433,7 +433,7 @@ EOT
     },
     cc0 => {
         license => 'cc0',
-        slname  => 'CC0',
+        slname  => 'unrestricted',
         url     => 'http://creativecommons.org/publicdomain/zero/1.0/',
         blurb   => <<'EOT',
 This program is distributed under the CC0 1.0 Universal License:
@@ -465,7 +465,7 @@ EOT
     },
     gpl => {
         license => 'gpl',
-        slname  => 'GPL_2',
+        slname  => 'gpl_2',
         url     => 'http://www.gnu.org/licenses/gpl-2.0.html',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or modify
@@ -485,7 +485,7 @@ EOT
     },
     lgpl => {
         license => 'lgpl',
-        slname  => 'LGPL_2',
+        slname  => 'lgpl_2_1',
         url     => 'http://www.gnu.org/licenses/lgpl-2.1.html',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or
@@ -506,7 +506,7 @@ EOT
     },
     gpl3 => {
         license => 'gpl3',
-        slname  => 'GPL_3',
+        slname  => 'gpl_3',
         url     => 'http://www.gnu.org/licenses/gpl-3.0.html',
         blurb   => <<'EOT',
 This program is free software: you can redistribute it and/or modify
@@ -525,7 +525,7 @@ EOT
     },
     lgpl3 => {
         license => 'lgpl3',
-        slname  => 'LGPL_3',
+        slname  => 'lgpl_3_0',
         url     => 'http://www.gnu.org/licenses/lgpl-3.0.html',
         blurb   => <<'EOT',
 This program is free software; you can redistribute it and/or
@@ -545,7 +545,7 @@ EOT
     },
     agpl3 => {
         license => 'agpl3',
-        slname  => 'AGPL_2',
+        slname  => 'agpl_3',
         url     => 'http://www.gnu.org/licenses/agpl-3.0.html',
         blurb => <<'EOT',
 This program is free software; you can redistribute it and/or
@@ -565,7 +565,7 @@ EOT
     },
     apache => {
         license => 'apache',
-        slname  => 'Apache_2_0',
+        slname  => 'apache_2_0',
         url     => 'http://www.apache.org/licenses/LICENSE-2.0',
         blurb   => <<'EOT',
 Licensed under the Apache License, Version 2.0 (the "License");
@@ -583,7 +583,7 @@ EOT
     },
     qpl => {
         license => 'qpl',
-        slname  => 'QPL_1_0',
+        slname  => 'qpl_1_0',
         url     => 'http://www.opensource.org/licenses/QPL-1.0',
         blurb   => <<'EOT',
 This program is distributed under the Q Public License (QPL-1.0):
@@ -753,10 +753,12 @@ sub Makefile_PL_guts {
     
     my $slname = $self->{license_record} ? $self->{license_record}->{slname} : $self->{license};
 
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+
     return <<"HERE";
 use $self->{minperl};
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 use ExtUtils::MakeMaker;
 
 WriteMakefile(
@@ -802,10 +804,12 @@ sub MI_Makefile_PL_guts {
     
     my $license_url = $self->{license_record} ? $self->{license_record}->{url} : '';
 
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+
     return <<"HERE";
 use $self->{minperl};
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 use inc::Module::Install;
 
 name     '$self->{distro}';
@@ -822,6 +826,7 @@ resources (
    #IRC        => 'irc://irc.perl.org/#$self->{distro}',
    license    => '$license_url',
    #repository => 'git://github.com/$self->{author}/$self->{distro}.git',
+   #repository => 'https://bitbucket.org/$self->{author}/$self->{distro}',
    bugtracker => 'http://rt.cpan.org/NoAuth/Bugs.html?Dist=$self->{distro}',
 );
 
@@ -890,10 +895,12 @@ sub Build_PL_guts {
 
     my $slname = $self->{license_record} ? $self->{license_record}->{slname} : $self->{license};
     
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+
     return <<"HERE";
 use $self->{minperl};
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 use Module::Build;
 
 my \$builder = Module::Build->new(
@@ -1073,9 +1080,11 @@ sub create_t {
     my $self = shift;
     my @modules = @_;
 
-    my %t_files = $self->t_guts(@modules);
+    my ($t_files, $xt_files) = $self->t_guts(@modules);
 
-    my @files = map { $self->_create_t($_, $t_files{$_}) } keys %t_files;
+    my @files;
+    push @files, map { $self->_create_t('t',  $_, $t_files->{$_}) } keys %$t_files;
+    push @files, map { $self->_create_t('xt', $_, $xt_files->{$_}) } keys %$xt_files;
 
     return @files;
 }
@@ -1095,17 +1104,24 @@ sub t_guts {
     my @modules = @_;
 
     my %t_files;
+    my %xt_files;
     my $minperl = $self->{minperl};
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+
     my $header = <<"EOH";
 #!perl -T
 use $minperl;
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 use Test::More;
 
 EOH
     
     $t_files{'pod.t'} = $header.<<'HERE';
+unless ( $ENV{RELEASE_TESTING} ) {
+    plan( skip_all => "Author tests not required for installation" );
+}
+
 # Ensure a recent version of Test::Pod
 my $min_tp = 1.22;
 eval "use Test::Pod $min_tp";
@@ -1127,6 +1143,10 @@ ok_manifest();
 HERE
 
     $t_files{'pod-coverage.t'} = $header.<<'HERE';
+unless ( $ENV{RELEASE_TESTING} ) {
+    plan( skip_all => "Author tests not required for installation" );
+}
+
 # Ensure a recent version of Test::Pod::Coverage
 my $min_tpc = 1.08;
 eval "use Test::Pod::Coverage $min_tpc";
@@ -1164,7 +1184,7 @@ HERE
       "  module_boilerplate_ok('".$self->_module_to_pm_file($_)."');\n" for @modules;
 
     my $boilerplate_tests = @modules + 2 + $[;
-    $t_files{'boilerplate.t'} = $header.<<"HERE";
+    $xt_files{'boilerplate.t'} = $header.<<"HERE";
 plan tests => $boilerplate_tests;
 
 sub not_in_file_ok {
@@ -1217,15 +1237,16 @@ $module_boilerplate_tests
 
 HERE
 
-    return %t_files;
+    return( \%t_files, \%xt_files );
 }
 
 sub _create_t {
     my $self = shift;
+    my $directory = shift;  # 't' or 'xt'
     my $filename = shift;
     my $content = shift;
 
-    my @dirparts = ( $self->{basedir}, 't' );
+    my @dirparts = ( $self->{basedir}, $directory );
     my $tdir = File::Spec->catdir( @dirparts );
     if ( not -d $tdir ) {
         local @ARGV = $tdir;
@@ -1237,7 +1258,7 @@ sub _create_t {
     $self->create_file( $fname, $content );
     $self->progress( "Created $fname" );
 
-    return "t/$filename";
+    return join('/', $directory, $filename );
 }
 
 =head2 create_MB_MANIFEST
@@ -1303,7 +1324,7 @@ sub create_MANIFEST {
     $self->$manifest_method();
     $self->filter_lines_in_file(
         $fname,
-        qr/^t\/boilerplate\.t$/,
+        qr/^xt\/boilerplate\.t$/,
         qr/^ignore\.txt$/,
     );
 
@@ -1410,6 +1431,7 @@ sub create_ignores {
         generic  => 'ignore.txt',
         cvs      => '.cvsignore',
         git      => '.gitignore',
+        hg       => '.hgignore',
         manifest => 'MANIFEST.SKIP',
     );
 
@@ -1476,7 +1498,7 @@ EOF
 ,v$
 \B\.svn\b
 \b_darcs\b
-# (.git only in top-level, hence it's blocked above)
+# (.git or .hg only in top-level, hence it's blocked above)
 
 # Avoid temp and backup files.
 ~$
@@ -1499,7 +1521,7 @@ EOF
 \.rej$
 EOF
     };
-    $guts->{cvs} = $guts->{git} = $guts->{generic};
+    $guts->{hg} = $guts->{cvs} = $guts->{git} = $guts->{generic};
     
     return $guts->{$type};
 }
@@ -1581,10 +1603,10 @@ sub filter_lines_in_file {
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-module-starter at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically
-be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to the bugtracker for this project
+on GitHub at: L<https://github.com/xsawyerx/module-starter/issues>. I will be
+notified, and then you'll automatically be notified of progress on your bug
+as I make changes.
 
 =head1 AUTHOR
 
@@ -1612,12 +1634,14 @@ sub _module_header {
     my $self = shift;
     my $module = shift;
     my $rtname = shift;
+    my $warnings = sprintf 'warnings%s;', ($self->{fatalize} ? " FATAL => 'all" : '');
+
     my $content = <<"HERE";
 package $module;
 
 use $self->{minperl};
 use strict;
-use warnings FATAL => 'all';
+use $warnings
 
 \=head1 NAME
 
